@@ -1,20 +1,18 @@
-# -*- coding: utf-8 -*-
-
 import csv
 
+from django.core.exceptions import PermissionDenied
 from django.http import HttpResponse
-
 from openslides.agenda.models import Speaker
-from openslides.utils.views import View, PermissionMixin
+from openslides.utils.views import View
 
 
-class CSVExportView(PermissionMixin, View):
+class CSVExportView(View):
     """
     View to export the lists of speakers of all agenda items as csv.
     """
-    required_permission = 'agenda.can_manage_agenda'
-
     def get(self, request, *args, **kwargs):
+        if not request.user.has_perm('agenda.can_manage'):
+            raise PermissionDenied
         response = HttpResponse()
         response['Content-Disposition'] = 'attachment; filename=list_of_speakers.csv;'
         csv_writer = csv.writer(response)
@@ -28,6 +26,5 @@ class CSVExportView(PermissionMixin, View):
                 end_time = speaker.end_time.strftime('%d.%m.%Y %H:%M:%S')
             except AttributeError:
                 end_time = None
-            csv_writer.writerow([
-                speaker.item.get_title().encode('utf8'), unicode(speaker.person).encode('utf8'), begin_time, end_time])
+            csv_writer.writerow([str(speaker.item), str(speaker.user), begin_time, end_time])
         return response
